.. image:: https://img.shields.io/pypi/v/z3c.pagelet.svg
        :target: https://pypi.python.org/pypi/z3c.pagelet/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/z3c.pagelet.svg
        :target: https://pypi.org/project/z3c.pagelet/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/z3c.pagelet/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/z3c.pagelet/actions/workflows/tests.yml


.. image:: https://coveralls.io/repos/github/zopefoundation/z3c.pagelet/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/z3c.pagelet?branch=master



Pagelets are Zope 3 UI components. In particular they allow the developer to
specify content templates without worrying about the UI O-wrap.
